@@ -1,6 +1,15 @@
 context("ROI_plugins")
-suppressMessages(library(tidyverse))
-suppressMessages(library(ROI.plugin.ecos))
+
+suppressMessages(library('testthat'))
+suppressMessages(library('dplyr'))
+suppressMessages(library('magrittr'))
+suppressMessages(library('purrr'))
+suppressMessages(library('stringr'))
+suppressMessages(library('tibble'))
+suppressMessages(library('tidyr'))
+suppressMessages(library('ROI.plugin.ecos'))
+suppressMessages(library('fbar'))
+
 
 data("ecoli_core")
 data("iJO1366")
@@ -40,11 +49,12 @@ test_that("same results on iJO1366", {
     reactiontbl_to_expanded() %>%
     expanded_to_ROI()
   
-  ROI::ROI_applicable_solvers(mod)%>%
+  ROI::ROI_applicable_solvers(mod) %>%
     map(safely(~ ROI::ROI_solve(mod, solver=.))) %>%
     walk(~ expect_null(.$error)) %>% 
     keep(~is.null(.$error)) %>%
-    map('result')%>%
+    map('result') %>%
+    keep(~.$status$code==0) %>%
     map(ROI::solution) %>%
     walk(expect_length, n=2583) %>%
     walk(~ expect_true(all(is.finite(.))))
